Learn R Programming

tidySEM (version 0.2.10)

BLRT: Conduct Bootstrapped Likelihood Ratio Test

Description

Conduct Bootstrapped Likelihood Ratio Test to compare two mixture models.

Usage

BLRT(x, replications = 100, ...)

Value

A data.frame.

Arguments

x

An object for which a method exists.

replications

Integer reflecting the number of bootstrapped replications, defaults to 100.

...

further arguments to be passed to or from other methods.

Examples

Run this code
if (FALSE) {
df <- iris[, 1, drop = FALSE]
names(df) <- "x"
res <- mx_mixture(model = "x ~ m{C}*1
                           x ~~ v{C}*x", classes = 1:2, data = df)
BLRT(res, replications = 4)
}

Run the code above in your browser using DataLab