mx_lca: Estimate latent class analyses using OpenMx
Description
This function simplifies the specification of latent class models:
models that estimate membership of a categorical latent variable based on
binary or ordinal indicators.
Usage
mx_lca(data = NULL, classes = 1L, run = TRUE, ...)
Value
Returns an OpenMx::mxModel().
Arguments
data
The data.frame to be used for model fitting.
classes
A vector of integers, indicating which class solutions to
generate. Defaults to 1L. E.g., classes = 1:6,
run
Logical, whether or not to run the model. If run = TRUE,
the function calls OpenMx::mxTryHardOrdinal().
...
Additional arguments, passed to functions.
References
Van Lissa, C. J., Garnier-Villarreal, M., & Anadria, D. (2023).
Recommended Practices in Latent Class Analysis using the Open-Source
R-Package tidySEM. Structural Equation Modeling.
tools:::Rd_expr_doi("10.1080/10705511.2023.2250920")