BCH: Estimate an Auxiliary Model using the BCH Method
Description
Estimate an auxiliary model based on a latent classification
by means of mixture modeling (see mx_mixture).
The auxiliary model is treated as a multi-group model. All cases are used in
all groups, but they are weighted by group-specific BCH weights as described
in Bolck, Croon, & Hagenaars, 2004.
Usage
BCH(x, model, data, ...)
Arguments
x
An object for which a method exists.
model
An object that can be converted to an OpenMx model
using as_ram.
data
A data.frame on which the auxiliary model can be evaluated.
...
further arguments to be passed to or from other methods.
Value
An MxModel.
References
Bolck, A., Croon, M., & Hagenaars, J. (2004). Estimating latent
structure models with categorical variables: One-step versus three-step
estimators. Political Analysis, 12(1), 3<U+2013>27. <doi:10.2307/25791751>