powered by
Conduct Bootstrapped Likelihood Ratio Test to compare two mixture models.
BLRT(x, ...)
An object for which a method exists.
further arguments to be passed to or from other methods.
A data.frame.
# NOT RUN { df <- iris[, 1, drop = FALSE] names(df) <- "x" res <- mx_mixture(model = "x ~ m{C}*1 x ~~ v{C}*x", classes = 1:2, data = df) BLRT(res, replications = 4) # }
Run the code above in your browser using DataLab