powered by
Converts SEM models to RAM models for OpenMx.
OpenMx
as_ram(x, ...)
An object for which a method exists, such as a tidy_sem object, or character vector describing the user-specified model using the lavaan model syntax.
tidy_sem
Parameters passed on to other functions.
Returns an mxModel.
mxModel
For models specified using lavaan syntax, the procedure is as follows:
Apply lavaanify to the model. The default arguments to lavaanify correspond to those of the sem function.
lavaanify
model
sem
Convert each row of the resulting lavaan parameter table to a mxPath.
mxPath
Apply mxModel to the mxPaths to create an OpenMx model using RAM specification
# NOT RUN { as_ram("y ~ x") # }
Run the code above in your browser using DataLab