Given two datasets with ordinal variables, computes the lambda statistic, which is the chi-square statistic minus the degrees of freedom.
Examples
if (FALSE) { # \dontrun{
if(interactive()){
chi_sq(iris[1:2], iris[3:4])
}
} # }
Given two datasets with ordinal variables, computes the lambda statistic, which is the chi-square statistic minus the degrees of freedom.
if (FALSE) { # \dontrun{
if(interactive()){
chi_sq(iris[1:2], iris[3:4])
}
} # }