Learn R Programming

tidySEM (version 0.2.10)

get_fit: Get fit indices from objects

Description

Get fit indices from objects for which a method exists.

Usage

get_fit(x, ...)

Value

A data.frame.

Arguments

x

An object for which a method exists.

...

further arguments to be passed to or from other methods.

Examples

Run this code
if (FALSE) {
df <- iris[, 1, drop = FALSE]
names(df) <- "x"
res <- mx_mixture(model = "x ~ m{C}*1
                           x ~~ v{C}*x", classes = 1, data = df)
table_fit(res)
}

Run the code above in your browser using DataLab