powered by
Get fit indices from objects for which a method exists.
get_fit(x, ...)
A data.frame.
An object for which a method exists.
further arguments to be passed to or from other methods.
if (FALSE) { df <- iris[, 1, drop = FALSE] names(df) <- "x" res <- mx_mixture(model = "x ~ m{C}*1 x ~~ v{C}*x", classes = 1, data = df) table_fit(res) }
Run the code above in your browser using DataLab