powered by
Concatenate vectors after converting to character and removing NA values. See paste.
NA
paste
paste2(..., sep = " ", collapse = NULL, na.rm = TRUE)
one or more R objects, to be converted to character vectors.
a character string to separate the terms. Not NA_character_.
NA_character_
an optional character string to separate the results. Not NA_character_.
logical, indicating whether NA values should be stripped before concatenation. Not NA_character_.
A character vector of the concatenated values.
# NOT RUN { paste2("word", NA) # }
Run the code above in your browser using DataLab