Given two datasets, computes the correlation matrix for both, and then calculates the standardized root mean residual difference between these two correlation matrices.
Arguments
- x
An object for which a method of
stats::cor()exists (e.g,data.frame).- y
An object for which a method of
stats::cor()exists (e.g,data.frame).
Examples
if (FALSE) { # \dontrun{
if(interactive()){
srmr(iris[1:2], iris[3:4])
}
} # }